/*
APS Regression Workshop: Example 3

Data from D. Johnson et al. (2009). Plant Disease 93: 272-280.

Relationship between late blight incidence and cumulative 
solar radiation (sr) from 1 April to 31 July.

*/

data johnson;
input year sr incidence ;	
	loginc = log(incidence/100);		*<--possible transformation;
	logit = log(incidence/(100-incidence));
	cll = log(-log(1-(incidence/100)));
	logsr = log(sr);
datalines;
1990	2658	0.4
1991	2635	24
1992	2676	42
1993	2560	45
1994	2744	1.1
1995	2644	80
1996	2750	44
1997	2628	70
1998	2659	64
1999	2775	5
2000	2720	13
2001	2885	0.6
2002	2869	1.8
2003	2749	3
2004	2705	35
2005	2684	22
2006	2819	5.7
2007	2951	0.6
;

proc sort data=johnson out=johnson;		*<--put data in ascending order of SR;
	by sr;								*<--can help with certain types of plots;
run;

title 'Late blight vs. solar radiation (Johnson et al. 2009)';
proc gplot data=johnson;
	title2 'Simple graph';
	symbol1 v=dot c=blue h=1.4 i=none  ;
	plot incidence*sr ;
run;

*goptions reset=all; 
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=1.5 i=join r=2 line=3;
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;
run;

	*ods listing close;
	*ods html  path='c:\temp' (url=none) body='temp.html';

	*ods html;
	*ods graphics on;

proc reg data=johnson ;
	title2 'linear relation between Y (incidence) and X';
	model incidence = sr / r cli clm clb influence;
	plot incidence*sr ;
	plot incidence*sr / conf  ;
	plot incidence*sr / conf pred ;	*<--too many lines can obsure patterns in graph;
	plot student.*p.;
	plot rstudent.*p. ;
	plot r.*nqq.;
	output out=johnson_reg_inc p=inchat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
run;
	ods graphics off;
	ods html close;
	*ods listing;
run;

axis1 w=3 order= (2500 to 3000 by 100 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Solar irradiance');
axis2 w=3 order= (0 to 100 by 10) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 ' Late blight incidence');
proc gplot data=johnson_reg_inc;
title2 'Direct incidence model';
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=2 i=join r=2 line=3;
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;
plot (incidence inchat)*sr / overlay haxis=axis1 vaxis=axis2;
plot (incidence inchat lclm uclm)*sr / overlay haxis=axis1 vaxis=axis2 ;
run;

*---Now try a transformation of disease incidence, that prevents predicted
	Y from being below 0. Try ln(incidence) or logit(incidence)	vs. X (SR).;

